==> igniteui-react-core-16.16.1.tgz: package/esm5/lib/GridSelectedItemsChangedEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { GridSelectedItemsChangedEventArgsDescription } from "./GridSelectedItemsChangedEventArgsDescription";
/**
 * @hidden
 */
var GridSelectedItemsChangedEventArgsDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(GridSelectedItemsChangedEventArgsDescriptionMetadata, _super);
    function GridSelectedItemsChangedEventArgsDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    GridSelectedItemsChangedEventArgsDescriptionMetadata.b = function (a) {
        if (GridSelectedItemsChangedEventArgsDescriptionMetadata.a == null) {
            GridSelectedItemsChangedEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            GridSelectedItemsChangedEventArgsDescriptionMetadata.c(GridSelectedItemsChangedEventArgsDescriptionMetadata.a);
        }
        if (a.g(GridSelectedItemsChangedEventArgsDescriptionMetadata.a)) {
            return;
        }
        a.s(GridSelectedItemsChangedEventArgsDescriptionMetadata.a);
    };
    GridSelectedItemsChangedEventArgsDescriptionMetadata.c = function (a) {
        a.item("CurrentItems", "Collection:object:GridSelectedItemsCollection:Object");
        a.item("AddedItems", "Collection:object:GridSelectedItemsCollection:Object");
        a.item("RemovedItems", "Collection:object:GridSelectedItemsCollection:Object");
    };
    GridSelectedItemsChangedEventArgsDescriptionMetadata.d = function (a) {
        GridSelectedItemsChangedEventArgsDescriptionMetadata.b(a);
        a.u("GridSelectedItemsChangedEventArgs", function () { return new GridSelectedItemsChangedEventArgsDescription(); });
        a.t("GridSelectedItemsChangedEventArgs", GridSelectedItemsChangedEventArgsDescriptionMetadata.a);
    };
    GridSelectedItemsChangedEventArgsDescriptionMetadata.$t = markType(GridSelectedItemsChangedEventArgsDescriptionMetadata, 'GridSelectedItemsChangedEventArgsDescriptionMetadata');
    GridSelectedItemsChangedEventArgsDescriptionMetadata.a = null;
    return GridSelectedItemsChangedEventArgsDescriptionMetadata;
}(Base));
export { GridSelectedItemsChangedEventArgsDescriptionMetadata };

==> igniteui-react-core-18.1.2.tgz: package/esm5/lib/GridSelectedItemsChangedEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { GridSelectedItemsChangedEventArgsDescription } from "./GridSelectedItemsChangedEventArgsDescription";
/**
 * @hidden
 */
var GridSelectedItemsChangedEventArgsDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(GridSelectedItemsChangedEventArgsDescriptionMetadata, _super);
    function GridSelectedItemsChangedEventArgsDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    GridSelectedItemsChangedEventArgsDescriptionMetadata.b = function (a) {
        if (GridSelectedItemsChangedEventArgsDescriptionMetadata.a == null) {
            GridSelectedItemsChangedEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            GridSelectedItemsChangedEventArgsDescriptionMetadata.c(GridSelectedItemsChangedEventArgsDescriptionMetadata.a);
        }
        if (a.j(GridSelectedItemsChangedEventArgsDescriptionMetadata.a)) {
            return;
        }
        a.y(GridSelectedItemsChangedEventArgsDescriptionMetadata.a);
    };
    GridSelectedItemsChangedEventArgsDescriptionMetadata.c = function (a) {
        a.item("CurrentItems", "Collection:object:GridSelectedItemsCollection:Object");
        a.item("AddedItems", "Collection:object:GridSelectedItemsCollection:Object");
        a.item("RemovedItems", "Collection:object:GridSelectedItemsCollection:Object");
    };
    GridSelectedItemsChangedEventArgsDescriptionMetadata.d = function (a) {
        GridSelectedItemsChangedEventArgsDescriptionMetadata.b(a);
        a.aa("GridSelectedItemsChangedEventArgs", function () { return new GridSelectedItemsChangedEventArgsDescription(); });
        a.z("GridSelectedItemsChangedEventArgs", GridSelectedItemsChangedEventArgsDescriptionMetadata.a);
    };
    GridSelectedItemsChangedEventArgsDescriptionMetadata.$t = markType(GridSelectedItemsChangedEventArgsDescriptionMetadata, 'GridSelectedItemsChangedEventArgsDescriptionMetadata');
    GridSelectedItemsChangedEventArgsDescriptionMetadata.a = null;
    return GridSelectedItemsChangedEventArgsDescriptionMetadata;
}(Base));
export { GridSelectedItemsChangedEventArgsDescriptionMetadata };
